source('source-code/3-29-14-RossMacDonaldModel.R')
source('source-code/1-17-13-EarlyWarningROCCurve.R') #requires package 'sfsmisc'

#memory.size(60000)
##load baseline sims
load("StaticSimsNm500.Rdata") #stationary sims ('static')
##load critical sims
load("PopSizeSims500.Rdata") #sims approaching elimination ('critical')

##################################################################

##what is tstar here??

nsims<-500
period<-7*100 #number of days in one month * number of time steps per day (too many time steps - memory issues??)

time.periodic<-select.periodic(popsize.sims[[1]][,1], period)

##make matrix of infected human time series
infected<-matrix(numeric(length(time.periodic)*nsims), ncol=nsims)
for(i in 1:nsims){
  infected[,i]<-select.periodic(popsize.sims[[i]][,2], period)
}

simlength<-length(popsize.sims[[1]][,1])

infected.baseline<-matrix(numeric(length(time.periodic)*nsims), ncol=nsims)
for(i in 1:nsims){
  infected.baseline[,i]<-select.periodic(staticNm.sims[[i]][(1:simlength),2], period) #up to the critical time tstar
}

bin.infected<-matrix(numeric(length(time.periodic)*nsims), ncol=nsims)
for(i in 1:nsims){
  bin.infected[,i]<-rbinom(length(time.periodic), round(infected[,i]), 0.9)
}

bin.infected.baseline<-matrix(numeric(length(time.periodic)*nsims), ncol=nsims)
for(i in 1:nsims){
  bin.infected.baseline[,i]<-rbinom(length(time.periodic), round(infected.baseline[,i]), 0.9)
}

##################################################################

##calculate fluctuations using Gaussian detrending

##Gaussian detrending critical data
T<-time.periodic

bandwidth<-80 #30 seems to work? how big should the fluctuations be?? see Dakos..eg 1000 too large, spurious in the tail
kernelFit<-matrix(NaN, ncol=nsims, nrow=length(infected[,1]))
for(i in 1:nsims){
  kernelFit[,i]<-ksmooth(T, infected[,i], "normal", bandwidth=bandwidth, n.points=length(T))$y
}
##calculate the residuals (mean given by KernelFit)
residuals<-(infected - kernelFit)#/sqrt(N0) ##should be scaled? check theory

#plot(residuals[,1], type='l',col=2)
#plot(kernelFit[,1], type='l')

##Gaussian detrending baseline data
T<-time.periodic

bandwidth<-80 #30 seems to work? how big should the fluctuations be?? see Dakos..eg 1000 too large, spurious in the tail
kernelFit.baseline<-matrix(NaN, ncol=nsims, nrow=length(infected.baseline[,1]))
for(i in 1:nsims){
  kernelFit.baseline[,i]<-ksmooth(T, infected.baseline[,i], "normal", bandwidth=bandwidth, n.points=length(T))$y
}
##calculate the residuals (mean given by KernelFit)
residuals.baseline<-(infected.baseline - kernelFit.baseline)#/sqrt(N0) ##should be scaled? check theory

#plot(residuals.baseline[,1], type='l',col=2)
#plot(kernelFit.baseline[,1], type='l')

##################################################################

##critical summary stats
var.movingwin<-matrix(NaN, ncol=nsims, nrow=length(T))
acf.movingwin<-matrix(NaN, ncol=nsims, nrow=length(T))
mean.movingwin<-matrix(NaN, ncol=nsims, nrow=length(T))
sd.movingwin<-matrix(NaN, ncol=nsims, nrow=length(T))

for(i in 1:nsims){
  var.movingwin[,i]<-process(residuals[,i], window.size=round(length(T)/2), stat.fn="var")
  acf.movingwin[,i]<-process(residuals[,i], window.size=round(length(T)/2), stat.fn="acf.lag1")
  ##calculations for CV
  mean.movingwin[,i]<-process(infected[,i], window.size=round(length(T)/2), stat.fn="mean")
  sd.movingwin[,i]<-process(infected[,i], window.size=round(length(T)/2), stat.fn="sd")
}

##median and Kendall's tau
tauvar<-apply(var.movingwin, 2, Kendall.tau)
#hist(tauvar, 50, col='gray75')
tauacf<-apply(acf.movingwin, 2, Kendall.tau)
#hist(tauacf, 50, col='gray75')

avgvar.movingwin<-apply(var.movingwin, 1, median)
avgacf.movingwin<-apply(acf.movingwin, 1, median)

bounds.acf<-apply(acf.movingwin, 1, quantile, probs=c(.025,.975), na.rm=TRUE)
bounds.var<-apply(var.movingwin, 1, quantile, probs=c(0.025, 0.975), na.rm=TRUE)

coefficient.variation<-sd.movingwin/(mean.movingwin)
avgcoef.movingwin<-apply(coefficient.variation, 1, median)

bounds.coef<-apply(coefficient.variation, 1, quantile, probs=c(0.025, 0.975), na.rm=TRUE)

taucoef<-apply(coefficient.variation, 2, Kendall.tau)
#hist(taucoef, 50, col='gray75')

##################################################################

##baseline sims
##summary stats
var.movingwin.baseline<-matrix(NaN, ncol=nsims, nrow=length(T))
acf.movingwin.baseline<-matrix(NaN, ncol=nsims, nrow=length(T))
mean.movingwin.baseline<-matrix(NaN, ncol=nsims, nrow=length(T))
sd.movingwin.baseline<-matrix(NaN, ncol=nsims, nrow=length(T))

for(i in 1:nsims){
  var.movingwin.baseline[,i]<-process(residuals.baseline[,i], window.size=round(length(T)/2), stat.fn="var")
  acf.movingwin.baseline[,i]<-process(residuals.baseline[,i], window.size=round(length(T)/2), stat.fn="acf.lag1")
  ##calculations for CV
  mean.movingwin.baseline[,i]<-process(infected.baseline[,i], window.size=round(length(T)/2), stat.fn="mean")
  sd.movingwin.baseline[,i]<-process(infected.baseline[,i], window.size=round(length(T)/2), stat.fn="sd")
}

##median and Kendall's tau
tauvar.baseline<-apply(var.movingwin.baseline, 2, Kendall.tau)
#hist(tauvar.baseline, 50, col='gray75')
tauacf.baseline<-apply(acf.movingwin.baseline, 2, Kendall.tau)
#hist(tauacf.baseline, 50, col='gray75')

avgvar.movingwin.baseline<-apply(var.movingwin.baseline, 1, median)
avgacf.movingwin.baseline<-apply(acf.movingwin.baseline, 1, median)

bounds.acf.baseline<-apply(acf.movingwin.baseline, 1, quantile, probs=c(.025,.975), na.rm=TRUE)
bounds.var.baseline<-apply(var.movingwin.baseline, 1, quantile, probs=c(0.025, 0.975), na.rm=TRUE)

coefficient.variation.baseline<-sd.movingwin.baseline/(mean.movingwin.baseline)
avgcoef.movingwin.baseline<-apply(coefficient.variation.baseline, 1, median)

bounds.coef.baseline<-apply(coefficient.variation.baseline, 1, quantile, probs=c(0.025, 0.975), na.rm=TRUE)

taucoef.baseline<-apply(coefficient.variation.baseline, 2, Kendall.tau)
#hist(taucoef.baseline, 50, col='gray75')

##ROC analysis
null.var.VK<-tauvar.baseline
test.var.VK<-tauvar

null.acf.VK<-tauacf.baseline
test.acf.VK<-tauacf

null.coef.VK<-taucoef.baseline
test.coef.VK<-taucoef

roc.var<-roc_data(dat=NULL, pts=200, null_dist=null.var.VK, test_dist=test.var.VK, silent=F)
roc.acf<-roc_data(dat=NULL, pts=200,null_dist=null.acf.VK, test_dist=test.acf.VK) ##warning message approx(roc[, 1], roc[, 2], n = 200) : collapsing to unique 'x' values
roc.coef<-roc_data(dat=NULL,pts=200, null_dist=null.coef.VK, test_dist=test.coef.VK) ##calculate ROC

auc.var<-integrate.xy(roc.var$False.positives, roc.var$True.positives)
auc.acf<-integrate.xy(roc.acf$False.positives, roc.acf$True.positives)
auc.coef<-integrate.xy(roc.coef$False.positives, roc.coef$True.positives)

##################################################################

####Figure 6####
#this will need tweaking

##ROC plot
time<-1:length(avgacf.movingwin) #monthly
x11(width=6.85,height=4.5)
#pdf(file='Figure6.pdf',width=6.85,height=4.5)
par(mfrow=c(3,2),mar=c(0,3,2,2),oma=c(3.5,2,0,0),tcl=0.3, mgp=c(0.5,0.5,0), las=1, cex=0.75)
plot(avgacf.movingwin~time,type='l',col=4,ylim=c(-0.2, 0.4), las=1, lwd=2,bty='l',xlab=NA, ylab=NA, xaxt='n', yaxt='n', xlim=c(0,length(time)))
##polygon for confidence intervals
polygon(c(time[round(length(T)/2):length(T)],rev(time[round(length(T)/2):length(T)])),
        c(bounds.acf[1,round(length(T)/2):length(T)], rev(bounds.acf[2,round(length(T)/2):length(T)])),col=rgb(0,0,1,1/10),lty = 3,border = FALSE)
lines(bounds.acf[1,], lty=3, col=4)
lines(bounds.acf[2,], lty=3, col=4)
axis(2, at=seq(-0.2,0.4,0.2), labels=TRUE)
axis(1, at=c(0, seq(10,length(T), 100)), labels=TRUE)
abline(v=length(T), lty=2)
#mtext(side=2,line=3, c("Autocorrelation"), las=0, cex=0.75)
mtext(side=2,line=3, c("Autocorrelation"), las=0, cex=0.9)
#mtext(paste("Fixed window size (in months) ",round(length(T)/2)), line=0.75, cex=0.75)
mtext(paste("Fixed window size (in weeks) ",round(length(T)/2)), line=0.75, cex=1)
#legend(0, 0.25, c('Van Kampen', 'Gaussian'),  lwd=2, bty='n', col=c(2, 'blue'))
#mtext(side=2, at=0.1, 'a',  font=2, line=3)
mtext(side=2, at=0.51, 'a',  font=2, line=3)

plot(roc.acf$True.positives~roc.acf$False.positives,  type='l', col=4,las=1,lwd=2, bty='l',xlab=NA, ylab=NA,  xaxt='n', yaxt='n') #acf no better than random...
text(0.8, 0.35, paste('AUC =',round(auc.acf,2)), col=4)
abline(a=0, b=1, lwd=2)
axis(2, at=seq(0, 1, 0.25), labels=TRUE)
axis(1, seq(0, 1, 0.25), labels=TRUE)
#mtext(side=2,line=3, c("True positive"), las=0, cex=0.75)
#mtext(side=3,line=0.75, expression(paste("ROC curve for Kendall's ",tau)), las=0, cex=0.75)
mtext(side=2,line=3, c("True positive"), las=0, cex=0.9)
mtext(side=3,line=0.75, expression(paste("ROC curve for Kendall's ",tau)), las=0, cex=1)
mtext(side=2, at=1.2, 'b',  font=2, line=3)

plot(avgvar.movingwin~time,type='l', las=1, lwd=2, bty='l',col=4, ylim=c(0, 60), xlab=NA, ylab=NA,  xaxt='n', yaxt='n', xlim=c(0,length(time))) #is variance predicted to decline?
polygon(c(time[round(length(T)/2):length(T)],rev(time[round(length(T)/2):length(T)])),
        c(bounds.var[1,round(length(T)/2):length(T)], rev(bounds.var[2,round(length(T)/2):length(T)])),col=rgb(0,0,1,1/10),lty = 3,border = FALSE)
lines(bounds.var[1,], lty=3, col=4)
lines(bounds.var[2,], lty=3, col=4)
axis(2, at=seq(0,60,20), labels=TRUE)
axis(1, at=c(0, seq(10,length(T), 100)), labels=TRUE)
#mtext(side=2,line=3, c("Variance"), las=0, cex=0.75)
mtext(side=2,line=3, c("Variance"), las=0, cex=0.9)
mtext(side=1,line=8, cex=1.25,c("Time (in months)"), las=0, outer=TRUE)
abline(v=length(T), lty=2)
mtext(side=2, at=60, 'c',  font=2, line=3)

plot(roc.var$True.positives~roc.var$False.positives, type='l', col=4,las=1,lwd=2, bty='l',xlab=NA, ylab=NA,  xaxt='n', yaxt='n')
abline(a=0, b=1, lwd=2)
axis(2, at=seq(0, 1, 0.25), labels=TRUE)
axis(1, seq(0, 1, 0.25), labels=TRUE)
text(0.8, 0.35, paste('AUC =',round(auc.var,2)), col=4)
#mtext(side=2,line=3, c("True positive"), las=0, cex=0.75)
mtext(side=2,line=3, c("True positive"), las=0, cex=0.9)
mtext(side=2, at=1.1, 'd',  font=2, line=3)

plot(avgcoef.movingwin~time,type='l', lty=1, las=1,col=4, lwd=2, bty='l',xlab=NA, ylab=NA,  xaxt='n', yaxt='n', xlim=c(0,length(time)), ylim=c(0, 0.1))
polygon(c(time[round(length(T)/2):length(T)],rev(time[round(length(T)/2):length(T)])),
        c(bounds.coef[1,round(length(T)/2):length(T)], rev(bounds.coef[2,round(length(T)/2):length(T)])),col=rgb(0,0,1,1/10),lty = 3,border = FALSE)
lines(bounds.coef[1,], lty=3, col=4)
lines(bounds.coef[2,], lty=3, col=4)
abline(v=length(T), lty=2)
axis(2, at=seq(0, 0.1, 0.05), labels=TRUE)
axis(1, at=c(0, seq(10,length(T), 100)), labels=TRUE)
#mtext(side=2,line=3, c("CV"), las=0, cex=0.75)
mtext(side=2,line=3, c("CV"), las=0, cex=0.9)
mtext(side=1,line=8, cex=1.25,c("Time"), las=0, outer=TRUE)
#mtext(side=1,line=2, c("Time (in months)"), las=0, cex=0.75)
mtext(side=1,line=2, c("Time (in weeks)"), las=0, cex=1)
mtext(side=2, at=0.11, 'e',  font=2, line=3)

plot(roc.coef$True.positives~roc.coef$False.positives, las=1,lwd=2,lty=1, bty='l',xlab=NA, ylab=NA, xaxt='n', yaxt='n',type='l', col=4)
abline(a=0, b=1, lwd=2)
#mtext(side=1,line=2, c("False positive"), las=0, cex=0.75)
mtext(side=1,line=2, c("False positive"), las=0, cex=1)
#mtext(side=2,line=3, c("True positive"), las=0, cex=0.75)
mtext(side=2,line=3, c("True positive"), las=0, cex=0.9)
axis(2, at=seq(0, 1, 0.25), labels=TRUE)
axis(1, seq(0, 1, 0.25), labels=TRUE)
text(0.8, 0.35, paste('AUC =',round(auc.coef,2)), col=4)
mtext(side=2, at=1.1, 'f',  font=2, line=3)
#dev.off()

##################################################################
##################################################################
##################################################################

##Figure 6 with binomial sampling data

##underreporting
##calculate fluctuations using Gaussian detrending - bin

##Gaussian detrending critical data
T<-time.periodic

bandwidth<-80 #30 seems to work? how big should the fluctuations be?? see Dakos..eg 1000 too large, spurious in the tail
kernelFit<-matrix(NaN, ncol=nsims, nrow=length(infected[,1]))
for(i in 1:nsims){
  kernelFit[,i]<-ksmooth(T, bin.infected[,i], "normal", bandwidth=bandwidth, n.points=length(T))$y
}
##calculate the residuals (mean given by KernelFit)
residuals<-(bin.infected - kernelFit)#/sqrt(N0) ##should be scaled? check theory

#plot(residuals[,1], type='l',col=2)
#plot(kernelFit[,1], type='l')

##Gaussian detrending baseline data
T<-time.periodic

bandwidth<-80 #30 seems to work? how big should the fluctuations be?? see Dakos..eg 1000 too large, spurious in the tail
kernelFit.baseline<-matrix(NaN, ncol=nsims, nrow=length(infected.baseline[,1]))
for(i in 1:nsims){
  kernelFit.baseline[,i]<-ksmooth(T, bin.infected.baseline[,i], "normal", bandwidth=bandwidth, n.points=length(T))$y
}
##calculate the residuals (mean given by KernelFit)
residuals.baseline<-(bin.infected.baseline - kernelFit.baseline)#/sqrt(N0) ##should be scaled? check theory

#plot(residuals.baseline[,1], type='l',col=2)
#plot(kernelFit.baseline[,1], type='l')

##################################################################

##critical summary stats
var.movingwin<-matrix(NaN, ncol=nsims, nrow=length(T))
acf.movingwin<-matrix(NaN, ncol=nsims, nrow=length(T))
mean.movingwin<-matrix(NaN, ncol=nsims, nrow=length(T))
sd.movingwin<-matrix(NaN, ncol=nsims, nrow=length(T))

for(i in 1:nsims){
  var.movingwin[,i]<-process(residuals[,i], window.size=round(length(T)/2), stat.fn="var")
  acf.movingwin[,i]<-process(residuals[,i], window.size=round(length(T)/2), stat.fn="acf.lag1")
  ##calculations for CV
  mean.movingwin[,i]<-process(bin.infected[,i], window.size=round(length(T)/2), stat.fn="mean")
  sd.movingwin[,i]<-process(bin.infected[,i], window.size=round(length(T)/2), stat.fn="sd")
}

##median and Kendall's tau
tauvar<-apply(var.movingwin, 2, Kendall.tau)
#hist(tauvar, 50, col='gray75')
tauacf<-apply(acf.movingwin, 2, Kendall.tau)
#hist(tauacf, 50, col='gray75')

avgvar.movingwin<-apply(var.movingwin, 1, median)
avgacf.movingwin<-apply(acf.movingwin, 1, median)

bounds.acf<-apply(acf.movingwin, 1, quantile, probs=c(.025,.975), na.rm=TRUE)
bounds.var<-apply(var.movingwin, 1, quantile, probs=c(0.025, 0.975), na.rm=TRUE)

coefficient.variation<-sd.movingwin/(mean.movingwin)
avgcoef.movingwin<-apply(coefficient.variation, 1, median)

bounds.coef<-apply(coefficient.variation, 1, quantile, probs=c(0.025, 0.975), na.rm=TRUE)

taucoef<-apply(coefficient.variation, 2, Kendall.tau)
#hist(taucoef, 50, col='gray75')

##################################################################

##baseline sims
##summary stats
var.movingwin.baseline<-matrix(NaN, ncol=nsims, nrow=length(T))
acf.movingwin.baseline<-matrix(NaN, ncol=nsims, nrow=length(T))
mean.movingwin.baseline<-matrix(NaN, ncol=nsims, nrow=length(T))
sd.movingwin.baseline<-matrix(NaN, ncol=nsims, nrow=length(T))

for(i in 1:nsims){
  var.movingwin.baseline[,i]<-process(residuals.baseline[,i], window.size=round(length(T)/2), stat.fn="var")
  acf.movingwin.baseline[,i]<-process(residuals.baseline[,i], window.size=round(length(T)/2), stat.fn="acf.lag1")
  ##calculations for CV
  mean.movingwin.baseline[,i]<-process(bin.infected.baseline[,i], window.size=round(length(T)/2), stat.fn="mean")
  sd.movingwin.baseline[,i]<-process(bin.infected.baseline[,i], window.size=round(length(T)/2), stat.fn="sd")
}

##median and Kendall's tau
tauvar.baseline<-apply(var.movingwin.baseline, 2, Kendall.tau)
#hist(tauvar.baseline, 50, col='gray75')
tauacf.baseline<-apply(acf.movingwin.baseline, 2, Kendall.tau)
#hist(tauacf.baseline, 50, col='gray75')

avgvar.movingwin.baseline<-apply(var.movingwin.baseline, 1, median)
avgacf.movingwin.baseline<-apply(acf.movingwin.baseline, 1, median)

bounds.acf.baseline<-apply(acf.movingwin.baseline, 1, quantile, probs=c(.025,.975), na.rm=TRUE)
bounds.var.baseline<-apply(var.movingwin.baseline, 1, quantile, probs=c(0.025, 0.975), na.rm=TRUE)

coefficient.variation.baseline<-sd.movingwin.baseline/(mean.movingwin.baseline)
avgcoef.movingwin.baseline<-apply(coefficient.variation.baseline, 1, median)

bounds.coef.baseline<-apply(coefficient.variation.baseline, 1, quantile, probs=c(0.025, 0.975), na.rm=TRUE)

taucoef.baseline<-apply(coefficient.variation.baseline, 2, Kendall.tau)
#hist(taucoef.baseline, 50, col='gray75')

##ROC analysis
null.var.VK<-tauvar.baseline
test.var.VK<-tauvar

null.acf.VK<-tauacf.baseline
test.acf.VK<-tauacf

null.coef.VK<-taucoef.baseline
test.coef.VK<-taucoef

roc.var<-roc_data(dat=NULL, pts=200, null_dist=null.var.VK, test_dist=test.var.VK, silent=F)
roc.acf<-roc_data(dat=NULL, pts=200,null_dist=null.acf.VK, test_dist=test.acf.VK) ##warning message approx(roc[, 1], roc[, 2], n = 200) : collapsing to unique 'x' values
roc.coef<-roc_data(dat=NULL,pts=200, null_dist=null.coef.VK, test_dist=test.coef.VK) ##calculate ROC

auc.var<-integrate.xy(roc.var$False.positives, roc.var$True.positives)
auc.acf<-integrate.xy(roc.acf$False.positives, roc.acf$True.positives)
auc.coef<-integrate.xy(roc.coef$False.positives, roc.coef$True.positives)

##################################################################

####extra figure####

##ROC plot
time<-1:length(avgacf.movingwin) #monthly
x11(width=6.85,height=4.5)
#pdf(file='Figure6.pdf',width=6.85,height=4.5)
par(mfrow=c(3,2),mar=c(0,3,2,2),oma=c(3.5,2,0,0),tcl=0.3, mgp=c(0.5,0.5,0), las=1, cex=0.75)
plot(avgacf.movingwin~time,type='l',col=4,ylim=c(-0.2, 0.4), las=1, lwd=2,bty='l',xlab=NA, ylab=NA, xaxt='n', yaxt='n', xlim=c(0,length(time)))
###polygon for confidence intervals
polygon(c(time[round(length(T)/2):length(T)],rev(time[round(length(T)/2):length(T)])),
        c(bounds.acf[1,round(length(T)/2):length(T)], rev(bounds.acf[2,round(length(T)/2):length(T)])),col=rgb(0,0,1,1/10),lty = 3,border = FALSE)
lines(bounds.acf[1,], lty=3, col=4)
lines(bounds.acf[2,], lty=3, col=4)
axis(2, at=seq(-0.2,0.4,0.2), labels=TRUE)
axis(1, at=c(0, seq(10,length(T), 100)), labels=TRUE)
abline(v=length(T), lty=2)
#mtext(side=2,line=3, c("Autocorrelation"), las=0, cex=0.75)
mtext(side=2,line=3, c("Autocorrelation"), las=0, cex=0.9)
#mtext(paste("Fixed window size (in months) ",round(length(T)/2)), line=0.75, cex=0.75)
mtext(paste("Fixed window size (in weeks) ",round(length(T)/2)), line=0.75, cex=1)
#legend(0, 0.25, c('Van Kampen', 'Gaussian'),  lwd=2, bty='n', col=c(2, 'blue'))
#mtext(side=2, at=0.1, 'a',  font=2, line=3)
mtext(side=2, at=0.51, 'a',  font=2, line=3)

plot(roc.acf$True.positives~roc.acf$False.positives,  type='l', col=4,las=1,lwd=2, bty='l',xlab=NA, ylab=NA,  xaxt='n', yaxt='n') #acf no better than random...
text(0.8, 0.35, paste('AUC =',round(auc.acf,2)), col=4)
abline(a=0, b=1, lwd=2)
axis(2, at=seq(0, 1, 0.25), labels=TRUE)
axis(1, seq(0, 1, 0.25), labels=TRUE)
#mtext(side=2,line=3, c("True positive"), las=0, cex=0.75)
#mtext(side=3,line=0.75, expression(paste("ROC curve for Kendall's ",tau)), las=0, cex=0.75)
mtext(side=2,line=3, c("True positive"), las=0, cex=0.9)
mtext(side=3,line=0.75, expression(paste("ROC curve for Kendall's ",tau)), las=0, cex=1)
mtext(side=2, at=1.2, 'b',  font=2, line=3)

plot(avgvar.movingwin~time,type='l', las=1, lwd=2, bty='l',col=4, ylim=c(0, 60), xlab=NA, ylab=NA,  xaxt='n', yaxt='n', xlim=c(0,length(time))) #is variance predicted to decline?
polygon(c(time[round(length(T)/2):length(T)],rev(time[round(length(T)/2):length(T)])),
        c(bounds.var[1,round(length(T)/2):length(T)], rev(bounds.var[2,round(length(T)/2):length(T)])),col=rgb(0,0,1,1/10),lty = 3,border = FALSE)
lines(bounds.var[1,], lty=3, col=4)
lines(bounds.var[2,], lty=3, col=4)
axis(2, at=seq(0,60,20), labels=TRUE)
axis(1, at=c(0, seq(10,length(T), 100)), labels=TRUE)
#mtext(side=2,line=3, c("Variance"), las=0, cex=0.75)
mtext(side=2,line=3, c("Variance"), las=0, cex=0.9)
mtext(side=1,line=8, cex=1.25,c("Time (in months)"), las=0, outer=TRUE)
abline(v=length(T), lty=2)
mtext(side=2, at=60, 'c',  font=2, line=3)

plot(roc.var$True.positives~roc.var$False.positives, type='l', col=4,las=1,lwd=2, bty='l',xlab=NA, ylab=NA,  xaxt='n', yaxt='n')
abline(a=0, b=1, lwd=2)
axis(2, at=seq(0, 1, 0.25), labels=TRUE)
axis(1, seq(0, 1, 0.25), labels=TRUE)
text(0.8, 0.35, paste('AUC =',round(auc.var,2)), col=4)
#mtext(side=2,line=3, c("True positive"), las=0, cex=0.75)
mtext(side=2,line=3, c("True positive"), las=0, cex=0.9)
mtext(side=2, at=1.1, 'd',  font=2, line=3)


plot(avgcoef.movingwin~time,type='l', lty=1, las=1,col=4, lwd=2, bty='l',xlab=NA, ylab=NA,  xaxt='n', yaxt='n', xlim=c(0,length(time)), ylim=c(0, 0.1))
polygon(c(time[round(length(T)/2):length(T)],rev(time[round(length(T)/2):length(T)])),
        c(bounds.coef[1,round(length(T)/2):length(T)], rev(bounds.coef[2,round(length(T)/2):length(T)])),col=rgb(0,0,1,1/10),lty = 3,border = FALSE)
lines(bounds.coef[1,], lty=3, col=4)
lines(bounds.coef[2,], lty=3, col=4)
abline(v=length(T), lty=2)
axis(2, at=seq(0, 0.1, 0.05), labels=TRUE)
axis(1, at=c(0, seq(10,length(T), 100)), labels=TRUE)
#mtext(side=2,line=3, c("CV"), las=0, cex=0.75)
mtext(side=2,line=3, c("CV"), las=0, cex=0.9)
mtext(side=1,line=8, cex=1.25,c("Time"), las=0, outer=TRUE)
#mtext(side=1,line=2, c("Time (in months)"), las=0, cex=0.75)
mtext(side=1,line=2, c("Time (in weeks)"), las=0, cex=1)
mtext(side=2, at=0.11, 'e',  font=2, line=3)

plot(roc.coef$True.positives~roc.coef$False.positives, las=1,lwd=2,lty=1, bty='l',xlab=NA, ylab=NA, xaxt='n', yaxt='n',type='l', col=4)
abline(a=0, b=1, lwd=2)
#mtext(side=1,line=2, c("False positive"), las=0, cex=0.75)
mtext(side=1,line=2, c("False positive"), las=0, cex=1)
#mtext(side=2,line=3, c("True positive"), las=0, cex=0.75)
mtext(side=2,line=3, c("True positive"), las=0, cex=0.9)
axis(2, at=seq(0, 1, 0.25), labels=TRUE)
axis(1, seq(0, 1, 0.25), labels=TRUE)
text(0.8, 0.35, paste('AUC =',round(auc.coef,2)), col=4)
mtext(side=2, at=1.1, 'f',  font=2, line=3)
#dev.off()
