source('source-code/3-29-14-RossMacDonaldModel.R')

kstarparams<-c(delta=0.1, mu=0.01,  p=0.5,  q=0.5, Nh=1000, Nm=10000)
kstar<-CalcKstar(kstarparams)
mustarparams<-c(k=0.3,  delta=0.1,  p=0.5,  q=0.5, Nh=1000, Nm=10000)
mustar<-CalcMustar(mustarparams)
deltastarparams<-c(k=0.3,   mu=0.01, p=0.5,  q=0.5, Nh=1000, Nm=10000)
deltastar<-CalcDeltastar(deltastarparams)  
Nmstarparams<-c(k=0.3,  delta=0.1,  mu=0.01, p=0.5,  q=0.5, Nh=1000)
Nmstar<-CalcNmstar(Nmstarparams)

Nm<-read.csv('csv/Nm.csv',header=FALSE)
Nmev1<-read.csv('csv/Nmev1.csv',header=FALSE)
Nmev2<-read.csv('csv/Nmev2.csv',header=FALSE)
k<-read.csv('csv/k.csv',header=FALSE)
kev1<-read.csv('csv/ev1k.csv',header=FALSE)
kev2<-read.csv('csv/ev2k.csv',header=FALSE)
mu<-read.csv('csv/mu.csv',header=FALSE)
muev1<-read.csv('csv/ev1mu.csv',header=FALSE)
muev2<-read.csv('csv/ev2mu.csv',header=FALSE)
delta<-read.csv('csv/d.csv',header=FALSE)
deltaev1<-read.csv('csv/ev1d.csv',header=FALSE)
deltaev2<-read.csv('csv/ev2d.csv',header=FALSE)

##################################################################

####Figure 10####
postscript(file='Figure10.eps',width=6.85,height=4.5)
#pdf(file='Figure10.pdf',width=6.85,height=6)
par(mfrow=c(2,2),mar=c(1,2,3,3),oma=c(4,4,1,0),tcl=0.3, mgp=c(0.5,0.5,0), las=1, cex=0.75)
plot(Nmev1[,1]~Nm[,1], type='l',bty='l',xlab=NA, ylab=NA,lwd=3,col='blue', lty=3, xaxt='n', yaxt='n', ylim=c(-1,0))
lines(Nmev2[,1]~Nm[,1],type='l',lwd=3,col='black', lty=3)
abline(v=Nmstar, lty=2, lwd=3, col='red')
axis(1, at=c(0,2500,5000,7500,10000), labels=TRUE)
axis(2, at=seq(-1, 0, 0.5), labels=TRUE)
mtext(side=2,line=2.5,c("Eigenvalues"), las=0, cex=1)
mtext(side=2,at=0, line=3,c("a"),font=2, las=1, cex=1)
mtext(side=1,line=1.8, c(expression(paste('Mosquito population', ~italic(N[m])))), las=0, cex=1)

plot(kev1[,1]~k[,1], type='l',bty='l',xlab=NA, ylab=NA,lwd=3,col='blue', lty=3, xaxt='n', yaxt='n',ylim=c(-1,0))
lines(kev2[,1]~k[,1],type='l',lwd=3,col='black', lty=3)
axis(1, at=seq(0, 0.3,0.1), labels=TRUE)
axis(2, at=seq(-1, 0, 0.5), labels=TRUE)
abline(v=kstar, lty=2, lwd=3, col='red')
mtext(side=2,line=2.5,c("Eigenvalues"), las=0, cex=1)
mtext(side=2,at=0, line=3,c("b"),font=2, las=1, cex=1)
mtext(side=1,line=1.8, c(expression(paste('Biting rate', ~italic(k)))), las=0, cex=1)

plot(muev1[,1]~mu[,1], type='l',bty='l',xlab=NA, ylab=NA,lwd=3,col='blue', lty=3, xaxt='n', yaxt='n',ylim=c(-5,0))
lines(muev2[,1]~mu[,1],type='l',lwd=3,col='black', lty=3)
abline(v=mustar, lty=2, lwd=3, col='red')
axis(1, at=c(0,0.5,1,1.5,2), labels=TRUE)
axis(2, at=seq(-5, 0, 2.5), labels=TRUE)
mtext(side=2,line=2.5,c("Eigenvalues"), las=0, cex=1)
mtext(side=2,at=0, line=3,c("c"),font=2, las=1, cex=1)
mtext(side=1,line=2,c(expression(paste('Recovery rate', ~mu))),  las=0, cex=1)

plot(deltaev1[,1]~delta[,1], type='l',bty='l',xlab=NA, ylab=NA,lwd=3,col='blue', lty=3, xaxt='n', yaxt='n',ylim=c(-5,0))
lines(deltaev2[,1]~delta[,1],type='l',lwd=3,col='black', lty=3)
abline(v=deltastar, lty=2, lwd=3, col='red')
axis(1, at=c(0,5,10,15,20), labels=TRUE)
axis(2, at=seq(-5, 0, 2.5), labels=TRUE)
mtext(side=2,line=2.5,c("Eigenvalues"), las=0, cex=1)
mtext(side=2,at=0, line=3,c("d"),font=2, las=1, cex=1)
mtext(side=1,line=2,c(expression(paste('Mortality rate', ~delta))),  las=0, cex=1)
legend(11, -2, c('dominant', 'subdominant'),lty=2, lwd=3, col=c(1,4), bty='n')
dev.off()
