source('source-code/3-29-14-RossMacDonaldModel.R')

##biting rate bifurcation diagram
params<-c(k=0.3, delta=0.1, mu=0.01,  p=0.5,  q=0.5, Nh=1000, Nm=10000)
kstar <- CalcKstar(params)

k.seq <- seq(kstar, 0.1, 0.005)

#equilibrium points
eq.H.k <- rep(0, length(k.seq))
for (i in 1:(length(k.seq))){
params<-c(k=k.seq[i], delta=0.1, mu=0.01,  p=0.5,  q=0.5, Nh=1000, Nm=10000)
eq.H.k[i]<-EE(params)[1]
}

zero.k.seq <-seq(0, kstar, 0.005)
k.seq <- c(zero.k.seq[-(length(zero.k.seq))], k.seq)
dfe.k<-rep(0, length(zero.k.seq))
eq.H.k <- c(dfe.k,eq.H.k[-1])

##population size
params<-c(k=0.3, delta=0.1, mu=0.01,  p=0.5,  q=0.5, Nh=1000, Nm=10000)
Nmstar <- CalcNmstar(params)

Nm.seq <- seq(Nmstar, 1000, 10)

#equilibrium points
eq.H.Nm <- rep(0,length(Nm.seq))
for (i in 1:(length(Nm.seq))){
  params<-c(k=0.3, delta=0.1, mu=0.01,  p=0.5,  q=0.5, Nh=1000, Nm=Nm.seq[i])
  eq.H.Nm[i]<-EE(params)[1] #human population only
}

zero.Nm.seq <-seq(0, Nmstar, 1)
Nm.seq <- c(zero.Nm.seq[-(length(zero.Nm.seq))], Nm.seq)
dfe.Nm<-rep(0, length(zero.Nm.seq))
eq.H.Nm <- c(dfe.Nm,eq.H.Nm[-1])

##recovery rate
params<-c(k=0.3, delta=0.1, mu=0.01,  p=0.5,  q=0.5, Nh=1000, Nm=10000)
mustar <- CalcMustar(params)

Mu.seq <- seq(0.01, mustar, 0.1)

#equilibrium points
eq.H.Mu <- rep(0, length(Mu.seq))
for (i in 1:(length(Mu.seq))){
  params<-c(k=0.3, delta=0.1, mu=Mu.seq[i],  p=0.5,  q=0.5, Nh=1000, Nm=10000)
  eq.H.Mu[i]<-EE(params)[1] #human population only
}

zero.Mu.seq <-seq(mustar+0.1, 3, 0.1)
Mu.seq <- c(Mu.seq, zero.Mu.seq)
dfe.mu<-rep(0, length(zero.Mu.seq))
eq.H.Mu <- c(eq.H.Mu, dfe.mu)

##mortality rate
params<-c(k=0.3, delta=0.1, mu=0.01,  p=0.5,  q=0.5, Nh=1000, Nm=10000)
deltastar <- CalcDeltastar(params)

delta.seq <- seq(0.1, deltastar, 0.1)

#equilibrium points
eq.H.delta <- rep(0, length(delta.seq))
for (i in 1:(length(delta.seq))){
  params<-c(k=0.3, delta=delta.seq[i], mu=0.01,  p=0.5,  q=0.5, Nh=1000, Nm=10000)
  eq.H.delta[i]<-EE(params)[1] #human population only
}

zero.delta.seq <-seq(deltastar+0.1, 25, 0.1)
delta.seq <- c(delta.seq, zero.delta.seq)
dfe.delta<-rep(0, length(zero.delta.seq))
eq.H.delta <- c(eq.H.delta, dfe.delta)

##################################################################

####Figure 1####
#2*2 plot
#x11(width=6.85/2,height=3) #put in greek letters
#pdf(file='Figure1.pdf',width=6.85/2,height=3)
par(mfrow=c(2,2),mar=c(2.5,2,1.75,2),oma=c(1.5,3,0,0.5),tcl=0.3, mgp=c(0.5,0.5,0), las=1, cex=0.73)
plot(eq.H.k~k.seq, type='l', col='black', lwd=3, las=1, bty='l',xlab=NA, ylab=NA,xaxt='n', yaxt='n')
axis(side=1, at=c(seq(0, 0.1, 0.05)), labels=c(seq(0, 0.1, 0.05)))#, expression(paste(~p^textstyle("*"))), 1)
axis(side=2, seq(0,1000, 200), labels=TRUE)
mtext(side=2, at=1050, 'a',  font=2, line=2.6)
#abline(v=kstar, lty=2, col='gray75', lwd=2)
#legend(-0.01, 1.15, c(expression(paste("imports ", (eta==1/5000))), expression(paste("limit case: no imports ", (eta==0)))), lty=1:2, col=c('black', 'red'), bty='n', lwd=c(2,1))
mtext(c('Infected host population size'), side=2,line=1.5, las=0, outer=TRUE, at=0.5, cex=0.95)
mtext(c(expression(paste('Biting rate', ~italic(k)))),  side=1,line=1.75, las=0, cex=0.85)
plot(eq.H.Nm~Nm.seq, type='l', col='black', lwd=3, las=1, bty='l',xlab=NA, ylab=NA,xaxt='n', yaxt='n')
axis(side=1, at=c(seq(0, 1000, 400)), labels=c(seq(0, 1000, 400)))#, expression(paste(~p^textstyle("*"))), 1)
axis(side=2, seq(0,1000, 200), labels=TRUE)
mtext(side=2, at=1000, 'b',  font=2, line=2.6)
mtext(c(expression(paste('Mosquito population', ~italic(N[m])))),  side=1,line=1.75, las=0, cex=0.75)
plot(eq.H.Mu~Mu.seq, type='l', col='black', lwd=3, las=1, bty='l',xlab=NA, ylab=NA,xaxt='n', yaxt='n')
axis(side=1, at=c(seq(0, 3, 1)), labels=c(seq(0, 3,1)))#, expression(paste(~p^textstyle("*"))), 1)
axis(side=2, seq(0,1000, 200), labels=TRUE)
mtext(c(expression(paste('Recovery rate', ~mu))), side=1,line=1.75, las=0, cex=0.75)
mtext(side=2, at=1200, 'c',  font=2, line=2.6)
plot(eq.H.delta~delta.seq, type='l', col='black', lwd=3, las=1, bty='l',xlab=NA, ylab=NA,xaxt='n', yaxt='n')
axis(side=1, at=c(seq(0,25, 10)), labels=c(seq(0, 25,10)))
axis(side=2, seq(0,1000, 200), labels=TRUE)
mtext(c(expression(paste('Mortality rate', ~delta))), side=1,line=1.75, las=0, cex=0.85)
mtext(side=2, at=1200, 'd',  font=2, line=2.6)
#dev.off()

####single figure: only biting rate k####
par(mfrow=c(1,1),mar=c(2.5,2,1.75,2),oma=c(1.5,3,0,0.5),tcl=0.3, mgp=c(0.5,0.5,0), las=1, cex=1.1)
plot(eq.H.k~k.seq, type='l', col='black', lwd=3, las=1, bty='l',xlab=NA, ylab=NA,xaxt='n', yaxt='n')
axis(side=1, at=c(seq(0, 0.1, 0.05)), labels=c(seq(0, 0.1, 0.05)))#, expression(paste(~p^textstyle("*"))), 1)
axis(side=2, seq(0,1000, 200), labels=TRUE)
#mtext(side=2, at=1050, 'a',  font=2, line=2.6)
#abline(v=kstar, lty=2, col='gray75', lwd=2)
#legend(-0.01, 1.15, c(expression(paste("imports ", (eta==1/5000))), expression(paste("limit case: no imports ", (eta==0)))), lty=1:2, col=c('black', 'red'), bty='n', lwd=c(2,1))
mtext(c('Infected host population size'), side=2,line=3, las=0,  cex=1.25)
mtext(c(expression(paste('Biting rate', ~italic(k)))),  side=1,line=2.5, las=0, cex=1.25)
