source('source-code/3-29-14-RossMacDonaldModel.R')

set.seed(9999)
params<-c(startk=0.3, deltak=0.0001, k=0.3, delta=0.1, mu=0.01,  p=0.5,  q=0.5, Nh=1000, Nm=10000)
kstar <- CalcKstar(params) #28
#need to figure out tstar (in days)
tstark <- CalcTstarK(params)

eq<-EE(params)
set.seed(99)
bitingsde<-DecreasingContactSDE(startk=0.3, deltak=0.0001, mu=0.01, delta=0.1, p=0.5,  q=0.5, Nm=10000, Nh=1000, sigma=0.05,(tstark+10000)*100, tstark+10000, eq[1], eq[2])

##popsize sde
params<-c(startNm=10000, deltaNm=1, Nm=10000, k=0.3, mu=0.01, delta=0.1, p=0.5,  q=0.5, Nh=1000)
Nmstar <- CalcNmstar(params) #28
#need to figure out tstar
tstarNm <- CalcTstarNm(params)
eq<-EE(params)

popsizesde <- DecreasingPopSizeSDE(startNm=10000, deltaNm=1, mu=0.01, delta=0.1, p=0.5,  q=0.5, k=0.3, Nh=1000, sigma=0.05,(tstarNm+1000)*100, tstarNm+1000, eq[1], eq[2])

##recovery sde
params<-c(startmu=0.01, deltamu=0.001, mu=0.01, k=0.3, mu=0.01, delta=0.1, p=0.5,  q=0.5, Nh=1000, Nm=10000)
mustar <- CalcMustar(params) #28
#need to figure out tstar (in days)
tstarMu <- CalcTstarmu(params)
eq<-EE(params)

recoverysde <-DecreasingRecoverySDE(startmu=0.01, deltamu=0.001, delta=0.1, p=0.5,  q=0.5, k=0.3, Nh=1000, Nm=10000, sigma=0.05,(tstarMu+100)*100, tstarMu+100, eq[1], eq[2])

##mortality sde
params<-c(startdelta=0.1, deltadelta=0.0025, delta=0.1, k=0.3, mu=0.01,  p=0.5,  q=0.5, Nh=1000, Nm=10000)
deltastar <- CalcDeltastar(params) #28
#need to figure out tstar (in days)
tstardelta <- CalcTstardelta(params)
eq<-EE(params)
#end at tstar0.0005
#x<-DecreasingMortalityRateSDE(startdelta=0.1, deltadelta=0.0025, mu=0.01, p=0.5,  q=0.5, k=0.3, Nh=1000, Nm=10000, sigma=0.05,tstar*100, tstar, eq[1], eq[2])

mortalitysde <-DecreasingMortalityRateSDE(startdelta=0.1, deltadelta=0.0025, mu=0.01, p=0.5,  q=0.5, k=0.3, Nh=1000, Nm=10000, sigma=0.05,(tstardelta+1000)*100, (tstardelta+1000), eq[1], eq[2])
  
period<-7*100 #number of days in one week * number of time steps per day 

bitingH.periodic<-select.periodic(bitingsde$H[1:400000], period)
bitingtime.periodic<-select.periodic(bitingsde$time[1:400000], period)
popsizeH.periodic<-select.periodic(popsizesde$H, period)
popsizetime.periodic<-select.periodic(popsizesde$time, period)
recoveryH.periodic<-select.periodic(recoverysde$H, period)
recoverytime.periodic<-select.periodic(recoverysde$time, period)
mortalityH.periodic<-select.periodic(mortalitysde$H, period)
mortalitytime.periodic<-select.periodic(mortalitysde$time, period)

##################################################################

####Figure 2####
#x11(width=6.85,height=4.5)
#pdf(file='Figure2.pdf', width=6.85,height=4.5)
#postscript(file='Figure2.eps')
par(mfrow=c(2,2),mar=c(1,2,2,1),oma=c(3,3,0,1),tcl=0.3, mgp=c(0.5,0.5,0), las=1, cex=0.7)
plot(bitingH.periodic~bitingtime.periodic, type='l', col='black', lwd=3, las=1, bty='l',xlab=NA, ylab=NA,xaxt='n', yaxt='n')
axis(side=1, seq(0,tstark+1000, 1000), labels=TRUE)
axis(side=2, seq(0,2000, 200), labels=TRUE)
mtext(side=3,  c(expression(paste('Biting rate', ~italic(k)))),  font=2, line=0, cex=0.8)
abline(v=tstark, lty=2)
mtext(side=2, at=1100, 'a',  font=2, line=2.3)
plot(popsizeH.periodic~popsizetime.periodic, type='l', col='black', lwd=3, las=1, bty='l',xlab=NA, ylab=NA,xaxt='n', yaxt='n')
axis(side=2, seq(0,1200, 200), labels=TRUE)
axis(side=1, seq(0,tstarNm+1000, 4000), labels=TRUE)
abline(v=tstarNm, lty=2)
mtext(side=2, at=1100, 'b',  font=2, line=2.3)
mtext(side=3,  c(expression(paste('Mosquito population', ~italic(N[m])))),  font=2, line=0, cex=0.8)
plot(recoveryH.periodic~recoverytime.periodic, type='l', col='black', lwd=3, las=1, bty='l',xlab=NA, ylab=NA,xaxt='n', yaxt='n')
axis(side=2, seq(0,1000, 200), labels=TRUE)
axis(side=1, seq(0,tstarMu+1000, 1000), labels=TRUE)
mtext(side=3,  c(expression(paste('Recovery rate', ~mu))),  font=2, line=-1, cex=0.8)
abline(v=tstarMu, lty=2)
mtext(side=2, at=1100, 'c',  font=2, line=2.3)
plot(mortalityH.periodic~mortalitytime.periodic, type='l', col='black', lwd=3, las=1, bty='l',xlab=NA, ylab=NA,xaxt='n', yaxt='n')
axis(side=2, seq(0,1000, 200), labels=TRUE)
axis(side=1, seq(0,tstardelta, 4000), labels=TRUE)
abline(v=tstardelta, lty=2)
mtext(side=2, at=1100, 'd',  font=2, line=2.3)
mtext(side=3, c(expression(paste('Mortality rate', ~delta))),  font=2, line=-1, cex=0.8)
mtext(c('Infected host population size'), side=2,line=1.5, las=0, outer=TRUE, at=0.45)
mtext(c('Time (in days)'), side=1,line=1.5, las=0, outer=TRUE)
#dev.off()

#x11(width=6.85/2,height=3) 
#pdf(file='Figure2.pdf', width=6.85/2,height=3)
